import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { PhysiqueTestVO, PhysiqueTestForm, PhysiqueTestQuery } from '@/api/ygpassport/physiqueTest/types';

/**
 * 查询学生体质健康测试数据列表
 * @param query
 * @returns {*}
 */

export const listPhysiqueTest = (query?: PhysiqueTestQuery): AxiosPromise<PhysiqueTestVO[]> => {
  return request({
    url: '/ygpassport/physiqueTest/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询学生体质健康测试数据详细
 * @param id
 */
export const getPhysiqueTest = (id: string | number): AxiosPromise<PhysiqueTestVO> => {
  return request({
    url: '/ygpassport/physiqueTest/' + id,
    method: 'get'
  });
};

/**
 * 新增学生体质健康测试数据
 * @param data
 */
export const addPhysiqueTest = (data: PhysiqueTestForm) => {
  return request({
    url: '/ygpassport/physiqueTest',
    method: 'post',
    data: data
  });
};

/**
 * 修改学生体质健康测试数据
 * @param data
 */
export const updatePhysiqueTest = (data: PhysiqueTestForm) => {
  return request({
    url: '/ygpassport/physiqueTest',
    method: 'put',
    data: data
  });
};

/**
 * 删除学生体质健康测试数据
 * @param id
 */
export const delPhysiqueTest = (id: string | number | Array<string | number>) => {
  return request({
    url: '/ygpassport/physiqueTest/' + id,
    method: 'delete'
  });
};
